/**
 * \file
 *
 * \brief This header shows that with the given Doxyfile, it warns about documented parameters.
 */

/**
\brief Example class.

Different functions show different situations.

Fn1 has one documented parameter, but

Output from doxygen is:
\code
/data/dev/doxygen/header.h:29: Warning: parameters of member example::Fn1 are not (all) documented
/data/dev/doxygen/header.h:38: Warning: parameters of member example::Fn2 are not (all) documented
/data/dev/doxygen/header.h:46: Warning: parameters of member example::Fn3 are not (all) documented
/data/dev/doxygen/header.h:56: Warning: parameters of member example::Fn4 are not (all) documented
/data/dev/doxygen/header.h:69: Warning: parameters of member example::Fn5 are not (all) documented
/data/dev/doxygen/header.h:38: Warning: parameters of member example::Fn2 are not (all) documented
/data/dev/doxygen/header.h:56: Warning: The following parameters of example::Fn4(int x, int y) are not documented:
parameter y
\endcode
 */
class example
{
public:
	example();
	virtual ~example();

	/**
	 * @brief No parameters at all.
	 */
	void Fn0( void );

	/**
	 * @brief One documented parameter.
	 *
	 * Function Fn1
	 *
	 * @param[in] x The one and only parameter and it is documented.
	 */
	void Fn1( int x );

	/**
	 * @brief Two undocumented parameters.
 	 *
	 * Function Fn2
	 *
	 */
	void Fn2( int x, int y );

/*!
\fn void example::Fn3(int x, int y)
\brief Two documented parameters.

Function Fn3

\param[in]	x	The first parameter and it is documented.
\param[in] y The second parameter and it is documented.
*/
void Fn3(int x, int y);

	/**
	 * @brief One undocumented parameter and one documented parameter.
	 *
	 * Function Fn4
	 *
	 * @param[in] x The first parameter and it is documented.
	 */
	void Fn4( int x, int y );

	/* Not documented here. */
	void Fn5( int x, int y );
};

/**
 * @brief Two documented parameters.
 *
 * Function Fn5
 *
 * @param[in] x The first parameter and it is documented.
 * @param[in] y The second parameter and it is documented.
 */
void example::Fn5( int x, int y )
{
}

